/// <reference types="node" />
import { EventEmitter } from "events";
import { ConstantsList, DiagnosticInfo, Packet, Region, Segment } from "./models";
export declare class CaptureInterface extends EventEmitter {
    private readonly _cap;
    private readonly _buf;
    private readonly _bufTable;
    private _opcodeLists;
    private _constants;
    private _packetDefs;
    private _region;
    private _opcodes;
    get constants(): ConstantsList | undefined;
    constructor(region?: Region);
    setRegion(region: Region): void;
    updateOpcodesCache(): void;
    open(deviceIdentifier: string): void;
    close(): void;
    private _loadOpcodes;
    private _loadConstants;
    private _getBuffer;
    private _discardUntilValid;
    private _tryGetFrameHeader;
    private _registerInternalHandlers;
    private _processFrame;
    static getDevices(): {
        name: string;
        description?: string;
        addresses: {
            addr: string;
            netmask: string;
            broadaddr?: string;
        }[];
        flags?: string;
    }[];
}
interface CaptureInterfaceEvents {
    ready: () => void;
    error: (err: Error) => void;
    packet: (packet: Packet) => void;
    segment: (segment: Segment<any>) => void;
    message: (type: string, message: Segment<any>) => void;
    diagnostics: (diagInfo: DiagnosticInfo) => void;
}
export declare interface CaptureInterface {
    on<U extends keyof CaptureInterfaceEvents>(event: U, listener: CaptureInterfaceEvents[U]): this;
    emit<U extends keyof CaptureInterfaceEvents>(event: U, ...args: Parameters<CaptureInterfaceEvents[U]>): boolean;
}
export {};
//# sourceMappingURL=pcap-ffxiv.d.ts.map